.. _astrodrizzle_:

**************************************
Primary User Interface: AstroDrizzle()
**************************************

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.astrodrizzle
   :members: AstroDrizzle
